# Changelog

## [0.1.1a1](https://github.com/OpenVoiceOS/ovos-ocp-rss-plugin/tree/0.1.1a1) (2025-06-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-rss-plugin/compare/0.1.0...0.1.1a1)

**Merged pull requests:**

- fix: compatibility with ovos-plugin-manager 1.X.X [\#7](https://github.com/OpenVoiceOS/ovos-ocp-rss-plugin/pull/7) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
